sortedcontainers: sorted collections library
================================================

Description
-----------

Sorted collections library, written in pure-Python

License
-------

Apache2

Upstream Contact
----------------

https://pypi.org/project/sortedcontainers

